import { HttpClient, HttpResponse as SdkHttpResponse, RequestOptionsFactory, RequestOptions } from '@wix/sdk-types';
import { HttpApiClient, HttpResponse, AggregateDataItemsRequest, AggregateDataItemsResponse, AggregatePipelineDataItemsRequest, AggregatePipelineDataItemsResponse, BulkInsertDataItemReferencesRequest, BulkInsertDataItemReferencesResponse, BulkInsertDataItemsRequest, BulkInsertDataItemsResponse, BulkRemoveDataItemReferencesRequest, BulkRemoveDataItemReferencesResponse, BulkRemoveDataItemsRequest, BulkRemoveDataItemsResponse, BulkPatchDataItemsRequest, BulkPatchDataItemsResponse, BulkSaveDataItemsRequest, BulkSaveDataItemsResponse, BulkUpdateDataItemsRequest, BulkUpdateDataItemsResponse, CountDataItemsRequest, CountDataItemsResponse, GetDataItemRequest, GetDataItemResponse, InsertDataItemRequest, InsertDataItemResponse, IsReferencedDataItemRequest, IsReferencedDataItemResponse, PatchDataItemRequest, PatchDataItemResponse, QueryDataItemsRequest, QueryDataItemsResponse, QueryDistinctValuesRequest, QueryDistinctValuesResponse, QueryReferencedDataItemsRequest, QueryReferencedDataItemsResponse, RemoveDataItemRequest, RemoveDataItemResponse, ReplaceDataItemReferencesRequest, ReplaceDataItemReferencesResponse, SaveDataItemRequest, SaveDataItemResponse, TruncateDataItemsRequest, TruncateDataItemsResponse, UpdateDataItemRequest, UpdateDataItemResponse, SearchDataItemsRequest, SearchDataItemsResponse, RequestInterceptor } from '@wix/wix-data-items-common';
export interface SideEffects {
    onSiteCall?: () => void;
    onSuccess?: (response: SdkHttpResponse<any>) => void;
    onError?: (error: any) => void;
}
export declare class WixDataItemsHttpClient implements HttpApiClient {
    private httpClient;
    private interceptor;
    private sideEffects?;
    constructor(httpClient: HttpClient, interceptor: RequestInterceptor<RequestOptions>, sideEffects?: SideEffects | undefined);
    getDataItem(request: GetDataItemRequest): Promise<HttpResponse<GetDataItemResponse>>;
    insertDataItem(request: InsertDataItemRequest): Promise<HttpResponse<InsertDataItemResponse>>;
    updateDataItem(request: UpdateDataItemRequest): Promise<HttpResponse<UpdateDataItemResponse>>;
    patchDataItem(request: PatchDataItemRequest): Promise<HttpResponse<PatchDataItemResponse>>;
    saveDataItem(request: SaveDataItemRequest): Promise<HttpResponse<SaveDataItemResponse>>;
    removeDataItem(request: RemoveDataItemRequest): Promise<HttpResponse<RemoveDataItemResponse>>;
    truncateDataItems(request: TruncateDataItemsRequest): Promise<HttpResponse<TruncateDataItemsResponse>>;
    bulkInsertDataItems(request: BulkInsertDataItemsRequest): Promise<HttpResponse<BulkInsertDataItemsResponse>>;
    bulkPatchDataItems(request: BulkPatchDataItemsRequest): Promise<HttpResponse<BulkPatchDataItemsResponse>>;
    bulkUpdateDataItems(request: BulkUpdateDataItemsRequest): Promise<HttpResponse<BulkUpdateDataItemsResponse>>;
    bulkSaveDataItems(request: BulkSaveDataItemsRequest): Promise<HttpResponse<BulkSaveDataItemsResponse>>;
    bulkRemoveDataItems(request: BulkRemoveDataItemsRequest): Promise<HttpResponse<BulkRemoveDataItemsResponse>>;
    isReferencedDataItem(request: IsReferencedDataItemRequest): Promise<HttpResponse<IsReferencedDataItemResponse>>;
    bulkInsertDataItemReferences(request: BulkInsertDataItemReferencesRequest): Promise<HttpResponse<BulkInsertDataItemReferencesResponse>>;
    bulkRemoveDataItemReferences(request: BulkRemoveDataItemReferencesRequest): Promise<HttpResponse<BulkRemoveDataItemReferencesResponse>>;
    replaceDataItemReferences(request: ReplaceDataItemReferencesRequest): Promise<HttpResponse<ReplaceDataItemReferencesResponse>>;
    countDataItems(request: CountDataItemsRequest): Promise<HttpResponse<CountDataItemsResponse>>;
    queryDistinctValues(request: QueryDistinctValuesRequest): Promise<HttpResponse<QueryDistinctValuesResponse>>;
    queryDataItems(request: QueryDataItemsRequest): Promise<HttpResponse<QueryDataItemsResponse>>;
    aggregateDataItems(request: AggregateDataItemsRequest): Promise<HttpResponse<AggregateDataItemsResponse>>;
    aggregatePipelineDataItems(request: AggregatePipelineDataItemsRequest): Promise<HttpResponse<AggregatePipelineDataItemsResponse>>;
    queryReferencedDataItems(request: QueryReferencedDataItemsRequest): Promise<HttpResponse<QueryReferencedDataItemsResponse>>;
    searchDataItems(request: SearchDataItemsRequest): Promise<HttpResponse<SearchDataItemsResponse>>;
    private execHttpCall;
}
export declare const getDataItemRequestOptions: RequestOptionsParams<'GET'>;
export declare const insertDataItemRequestOptions: RequestOptionsParams<'POST'>;
export declare const updateDataItemRequestOptions: RequestOptionsParams<'POST'>;
export declare const patchDataItemRequestOptions: RequestOptionsParams<'POST'>;
export declare const saveDataItemRequestOptions: RequestOptionsParams<'POST'>;
export declare const removeDataItemRequestOptions: RequestOptionsParams<'POST'>;
export declare const truncateDataItemsRequestOptions: RequestOptionsParams<'POST'>;
export declare const bulkInsertDataItemsRequestOptions: RequestOptionsParams<'POST'>;
export declare const bulkUpdateDataItemsRequestOptions: RequestOptionsParams<'POST'>;
export declare const bulkPatchDataItemsRequestOptions: RequestOptionsParams<'POST'>;
export declare const bulkSaveDataItemsRequestOptions: RequestOptionsParams<'POST'>;
export declare const bulkRemoveDataItemsRequestOptions: RequestOptionsParams<'POST'>;
export declare const isReferencedDataItemRequestOptions: RequestOptionsParams<'POST'>;
export declare const bulkInsertDataItemReferencesRequestOptions: RequestOptionsParams<'POST'>;
export declare const bulkRemoveDataItemReferencesRequestOptions: RequestOptionsParams<'POST'>;
export declare const replaceDataItemReferencesRequestOptions: RequestOptionsParams<'POST'>;
export declare const countDataItemsRequestOptions: RequestOptionsParams<'POST'>;
export declare const queryDistinctValuesRequestOptions: RequestOptionsParams<'POST'>;
export declare const queryDataItemsRequestOptions: RequestOptionsParams<'POST'>;
export declare const aggregateDataItemsRequestOptions: RequestOptionsParams<'POST'>;
export declare const aggregatePipelineDataItemsRequestOptions: RequestOptionsParams<'POST'>;
export declare const queryReferencedDataItemsRequestOptions: RequestOptionsParams<'POST'>;
export declare const searchDataItemsRequestOptions: RequestOptionsParams<'POST'>;
export type HttpMethod = 'POST' | 'GET' | 'DELETE' | 'PUT';
export interface RequestOptionsParams<T extends HttpMethod> {
    method: T;
    methodName: string;
    httpPath: string;
}
export declare const reqOptions: ({ method, methodName, httpPath }: RequestOptionsParams<HttpMethod>, payload: any) => RequestOptionsFactory;
export { AggregateDataItemsRequest, AggregateDataItemsResponse, BulkInsertDataItemReferencesRequest, BulkInsertDataItemReferencesResponse, BulkInsertDataItemsRequest, BulkInsertDataItemsResponse, BulkRemoveDataItemReferencesRequest, BulkRemoveDataItemReferencesResponse, BulkRemoveDataItemsRequest, BulkRemoveDataItemsResponse, BulkSaveDataItemsRequest, BulkSaveDataItemsResponse, BulkUpdateDataItemsRequest, BulkUpdateDataItemsResponse, CountDataItemsRequest, CountDataItemsResponse, GetDataItemRequest, GetDataItemResponse, InsertDataItemRequest, InsertDataItemResponse, IsReferencedDataItemRequest, IsReferencedDataItemResponse, QueryDataItemsRequest, QueryDataItemsResponse, QueryDistinctValuesRequest, QueryDistinctValuesResponse, QueryReferencedDataItemsRequest, QueryReferencedDataItemsResponse, PatchDataItemRequest, PatchDataItemResponse, BulkPatchDataItemsRequest, BulkPatchDataItemsResponse, RemoveDataItemRequest, RemoveDataItemResponse, ReplaceDataItemReferencesRequest, ReplaceDataItemReferencesResponse, SaveDataItemRequest, SaveDataItemResponse, TruncateDataItemsRequest, TruncateDataItemsResponse, UpdateDataItemRequest, UpdateDataItemResponse, SearchDataItemsRequest, SearchDataItemsResponse, };
